@@ -2,8 +2,7 @@ use std::env::current_dir;
 use std::fs::create_dir_all;
 
 use cosmwasm_schema::{export_schema, remove_schemas, schema_for};
-use cw20_base::msg::{InstantiateMsg, QueryMsg};
-use cw20_factory_token::msg::ExecuteMsg;
+use cw20_base::msg::{InstantiateMsg, QueryMsg, ExecuteMsg};
 
 
 fn main() {
