@@ -5,9 +5,9 @@ use cosmwasm_std::{
 };
 use cw20_base::ContractError;
 use cw20_base::enumerable::{query_all_allowances, query_all_accounts};
-use cw20_base::msg::QueryMsg;
+use cw20_base::msg::{QueryMsg,ExecuteMsg};
 
-use crate::msg::{ExecuteMsg, InstantiateMsg, MigrateMsg};
+use crate::msg::MigrateMsg;
 use cw2::set_contract_version;
 use cw20_base::allowances::{
     execute_decrease_allowance, execute_increase_allowance, execute_send_from,
@@ -27,14 +27,14 @@ pub fn instantiate(
     deps: DepsMut,
     env: Env,
     info: MessageInfo,
-    msg: InstantiateMsg,
+    msg: cw20_base::msg::InstantiateMsg,
 ) -> Result<Response, ContractError> {
     set_contract_version(deps.storage, CONTRACT_NAME, CONTRACT_VERSION)?;
 
     /* Execute the instantiate method from cw_20_base as the code from that
     library is already battle tested we do not have to re-write the full
     functionality: https://github.com/CosmWasm/cw-plus/tree/main/contracts/cw20-base*/
-    Ok(cw20_base::contract::instantiate(deps, env, info, msg.cw20)?)
+    Ok(cw20_base::contract::instantiate(deps, env, info, msg)?)
 }
 
 #[cfg_attr(not(feature = "library"), entry_point)]
